@@ -17,7 +17,7 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.0.11'
+    version = '1.0.12'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/dreamerldq/sentry-dingding-format'),
@@ -44,6 +44,17 @@ class DingDingPlugin(NotificationPlugin):
         """
         Process error.
         """
+
+        print("WB_GROUP", group )
+
+        print("WB_EVENT", event )
+
+
+        for var in args:
+            print ("WB_ARGS",var)
+        
+        print("WB_KWARGS",kwargs)
+
         if not self.is_configured(group.project):
             return
 
@@ -58,12 +69,12 @@ class DingDingPlugin(NotificationPlugin):
             "msgtype": "markdown",
             "markdown": {
                 "title": title,
-                "text": u"#### {title} \n\n > {message} \n\n > 设备:{device} \n\n > 报错次数:{count} \n\n > UID:{uid} \n\n > {path} \n\n [详细信息]({url})".format(
+                "text": u"#### {title} \n\n > {message} \n\n > 设备:{device} \n\n  > UID:{uid} \n\n > {path} \n\n [详细信息]({url})".format(
                     title=title,
                     device=event.get_tag('device'),
                     uid=event.get_tag('uid'),
                     path=event.get_tag('url'),
-                    count=event.group.count,
+                    
                     message=event.title or event.message,
                     url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                 )
